# worklight-access-token-validator

This node module purpose is to allow for an offline validation of Worklight server generated OAuth tokens.

## Usage

Usage of this module requires that you have access to the certificate used in the server for signing the tokens.
To extract the certificate from a JKS keystore you can use Java's keytool in the following manner:

```bash
keytool -exportcert -keystore $KEYSTORE_FILE -alias $CERTIFICATE_ALIAS -rfc > $OUTPUT_FILE.pem
```

You then have to pass the the content of the generated (PEM formatted) certificate file as input to the node module which will allow you to validate tokens created with the same certificate.

Please note that expiration of the token is checked against the local computer time so make sure your clock is synced (preferably using an NTP server).


# After installing the package with 'npm install *'
Using this module will give you a function that requires certificate (mandatory) and a scope (optional)
Once called with these params, you will have an object with the following functions:
- validate(token, callback):
	A function that validates if the token provided is a valid worklight access token.
	If scope param is given upon initialization, also validates that the token is for the required scope.
	params:
		token
		callback -  function(errorObject, authenticationData) ** both objects described below
- validateAuthorizationHeader(authHeader, callback):
	A helper function.
	Allows for developer to use it without having to parse the 'Authorization' header himself to retreive token
	params:
		authHeader
		callback - as described above

### Sample usage:
```javascript
// Load the certificate from a PEM encoded file
var cert = require("fs").readFileSync('cert.pem');

// The scope to mandate (can be null, in which case the token is only checked for a suitable signature and token expiration)
var scope = "WorklightSecurityTest";

// Create a reusable validator
var worklightValidator = require("worklight-access-token-validator")(cert, scope);


worklightValidator.validate(token, function(tokenError, authenticationData) {
	if (tokenError) {
		// Token is invalid, send appropriate response to user
		response.writeHead(tokenError.httpStatus,
				{
				 'Content-Type': 'text/html',
				 'WWW-Authenticate' : tokenError.wwwAuthenticateHeader
				});
	} else {
		// Token is valid, proceed with request
	}
});
```

### Error object
The error object in the callback method contains the following fields:
+ err - contains the error code, which can be one of:
	+ 'invalid_token'
	+ 'missing_token'
	+ 'insufficient_scope'
+ errMsg - contains the human readable description of the error reason.
+ httpStatus - the http status to use when responding to the access token sender
+ wwwAuthenticateHeader - the content of the 'WWW-Authenticate' header that should be responded to the access token sender

### Authentication data
The authentication data in the callback method contains the following fields:
+ version - version of the token
+ scope - the security test that the token authenticated
+ expiration - time in msec since epoch when token expires
+ data - object with the following fields
	++ user_id [optional] - authenticated user
	++ device_id [optional] - device id as known by worklight server
	++ application_id - identity of the app
